embassy-stm32

Crates

git

Versions

stm32h7s3a8

Flavors

set_and_enable_comp_vals

Function set_and_enable_comp_vals 

pub fn set_and_enable_comp_vals(cv: &CompVals)
Apply static slew-rate compensation values to all compensation cells, and enable them. These should be the corrected values outlined in the errata. (ES0596, p. 12, Ch 2.2.15 “I/O compensation could alter duty-cycle of high-frequency output signal”)