pub fn get_corrected_comp_vals() -> CompValsExpand description
Obtain the auto-tuned, slew-rate compensation values for the different compensation cells. The errata corrections are applied. Following the errata, these values should be obtained once during production, around 30°C MCU temperature, for each individual board, and stored in non-volatile memory for future use. The stored values should then be applied at power-up to guarantee stable, high-speed operation of the XSPI busses, and other high-speed I/O. While ST does not discuss the application to the GPIO pins in general in the errata, applying the errata compensation to those as well seems to improve the waveform symmetry (eg: MCO). (ES0596, p. 12, Ch 2.2.15 “I/O compensation could alter duty-cycle of high-frequency output signal”)